pub unsafe extern "C" fn webview_return(
w: *mut c_void,
id: *const i8,
status: i32,
result: *const i8,
) -> i32Expand description
Responds to a binding call from the JS side.
This function is safe to call from another thread.
@param w The webview instance. @param id The identifier of the binding call. Pass along the value received in the binding handler (see webview_bind()). @param status A status of zero tells the JS side that the binding call was successful; any other value indicates an error. @param result The result of the binding call to be returned to the JS side. This must either be a valid JSON value or an empty string for the primitive JS value @c undefined.